emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] scratch/with-url 1c59f8a 6/8: Get chunked decoding right


From: Lars Ingebrigtsen
Subject: [Emacs-diffs] scratch/with-url 1c59f8a 6/8: Get chunked decoding right
Date: Sun, 22 Jan 2017 22:25:23 +0000 (UTC)

branch: scratch/with-url
commit 1c59f8aac7c764484a858abfbf2ecd2a20f2f048
Author: Lars Ingebrigtsen <address@hidden>
Commit: Lars Ingebrigtsen <address@hidden>

    Get chunked decoding right
---
 lisp/url/with-url.el |    6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/lisp/url/with-url.el b/lisp/url/with-url.el
index b25493b..7e85d99 100644
--- a/lisp/url/with-url.el
+++ b/lisp/url/with-url.el
@@ -625,8 +625,10 @@ If given, return the value in BUFFER instead."
       (delete-region (match-beginning 0) (point))
       (if (zerop length)
           (delete-region (match-beginning 0) (point-max))
-        ;; Skip ahead, and then past the CRLF.
-        (goto-char (+ (point) length 2))))))
+        ;; Skip ahead.
+        (goto-char (+ (point) length))
+        ;; Delete the CRLF.
+        (delete-char 2)))))
 
 (defun with-url--redirect (process location)
   (let ((req (plist-get (process-plist process) :request)))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]